@@ -67,10 +67,12 @@ class Pipeline():
     def __init__(self, task='pipeline', num_gpus=1, log_dir='log'):
         ensure_dir(log_dir)
         logging.basicConfig(
-            format="%(asctime)s - %(levelname)s - %(name)s -   %(message)s",
-            datefmt="%m/%d/%Y %H:%M:%S",
+            format="%(asctime)s - %(levelname)s - %(name)s - %(message)s",
+            datefmt="%Y-%m-%d %H:%M:%S",
             level=logging.INFO,
-            filename=f"{log_dir}/{task}.txt", filemode='w')
+            filename=f"{log_dir}/{task}.txt",
+            filemode='w'
+        )
         self.logger = logging.getLogger(task)
         self.timer = Timer()
         self.gpu_manager = GPUManager(num_gpus=num_gpus)
